# Vowel Documentation

Welcome to the Vowel framework documentation.

## Contents

| Document | Description |
|----------|-------------|
| [User Guide](./USERGUIDE.md) | Complete guide to using Vowel |
| [API Reference](./API.md) | Detailed API documentation |

## Quick Links

- **Getting Started**: See [User Guide - Quick Start](./USERGUIDE.md#quick-start)
- **YAML Format**: See [User Guide - YAML Format](./USERGUIDE.md#yaml-specification)
- **Evaluators**: See [User Guide - Evaluators](./USERGUIDE.md#evaluators)
- **RunEvals API**: See [API - RunEvals](./API.md#runevals)
- **EvalGenerator**: See [API - EvalGenerator](./API.md#evalgenerator)
